@@ -28,6 +28,16 @@ class SGClimaDataAPI(BaseAPI):
         params = {"date": date}
         return self._call("/sites/{id}/health/calculate".format(id=id), params=params)
 
+    def get_site_health_history(self, site_id, start, end, threshold=70, max_consecutive_days_below=1):
+        params = {
+            "site_id": site_id,
+            "start": start,
+            "end": end,
+            "threshold": threshold,
+            "max_consecutive_days_below": max_consecutive_days_below
+        }
+        return self._call_json("/sites/{id}/health/history".format(id=site_id), params=params)["pids"]
+
     def get_zone_data(self, id, start, end):
         params = {"start": start, "end": end}
         df = self._call_df("/zones/{id}/data/download".format(id=id), params=params)
